# Architecture

An overview of the architecture of GAP is depicted in the following picture:

![](../assets/images/Architecture-WFO_Geant_specific.drawio.png)

The diagram visualises how GAP positions itself as a single point of access, not only for the interaction with a
specific technical domain. In our case with the IP/MPLS network, it also models the interaction with OSS/BSS systems
that are authoritative for certain types of resources.

GAP is responsible not only for allocation and release of these resources, but also for verification whether all systems
are in sync over time.

In other words, operators are no longer responsible for preparation of resources before performing changes (for example
allocating IP networks or addresses, and configuring DNS accordingly). The GAP component responsible for the interaction
with that particular system will take care of allocating and configuring the necessary resources.

Included in the orchestration layer there is a service database that stores all instances of the services in accordance
to their respective domain models. More details are available in the section
[GAP components](components/index.md)

## OSS/BSS systems currently in scope

### Infoblox

Infoblox is the GÉANT DDI (DHCP/DNS/IPAM) platform responsible for managing the allocation of IP networks and
addresses (both IPv4 and IPv6). It also assigns domain names in the zones that GÉANT is authoritative over.

Currently, GAP supports:

- Allocation and deletion of an IP (v4/v6) Network within an existing network container
- Allocation and deletion of a host and relative IPv4 and IPv6 addresses including `A`, `AAAA`, and `PTR` records

More detailed information about this integration is available in the
[IPAM integration module](../admin_guide/oss_bss/ipam.md).

### Netbox

Netbox is responsible for managing physical resources such as nodes and interfaces. More specifically, it contains all
the routers and their interfaces, and provides to WFO which of these interfaces are available for use.

An interface can be in 3 different states:

- __free__: available to be used by a workflow to deploy a service
- __reserved__: currently in use by a workflow that is still running
- __in use__: holding a service currently active

More detailed information about this integration is available in the
[Physical resources integration module](../admin_guide/oss_bss/netbox.md)

### LibreNMS

LibreNMS is a general purpose monitoring system in use at GÉANT to gather relevant metrics, checks, and facts.
LibreNMS is also the inventory for Oxidized: a network configuration backup system. It is used to have versioned
configuration backups of routers, switches, and any other network devices that are supported.

More detailed information about this integration is available in the
[LibreNMS integration module](../admin_guide/oss_bss/librenms.md).

### Kentik

Kentik is a Network Observability tool which collects various data points from deployed PE routers.
For this reason it is not in scope for PHASE1.

### Inventory provider

At the time of writing, the Inventory Provider gets the list of routers from the network engineering SOT servers.
This will change and Inventory Provider is then able to directly query CoreDB.
